@@ -9,7 +9,7 @@
  * Author: Steven Dake (sdake@redhat.com)
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -35,6 +35,8 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -51,10 +53,8 @@
 #include <net/if.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
-#include <assert.h>
 
 #include <saAis.h>
-#include <corosync/ipc_gen.h>
 #include "util.h"
 
 SaAisErrorT
@@ -94,7 +94,7 @@ saVersionVerify (
 			if (versionDatabase->versionsSupported[i].majorVersion >= version->majorVersion) {
 				error = SA_AIS_OK;
 				break;
-			} 
+			}
 
 			/*
 			 * We support the release code, but not the major version.
@@ -135,4 +135,3 @@ SaTimeT clustTimeNow(void)
 
 	return time_now;
 }
-
