@@ -9,7 +9,7 @@
  *
  * All rights reserved.
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -43,7 +43,11 @@
 #include <regex.h>
 #include <netinet/in.h>
 
-#include <corosync/ipc_gen.h>
+#include <corosync/corotypes.h>
+#include <corosync/coroipc_types.h>
+#include <corosync/coroipcc.h>
+#include <corosync/corodefs.h>
+#include <corosync/mar_gen.h>
 #include <corosync/engine/coroapi.h>
 #include <corosync/list.h>
 #include "../include/saAis.h"
@@ -131,7 +135,7 @@ typedef enum {
 	NODE_ACSM_LEAVING_SPONTANEOUSLY_WAITING_FOR_NODE_TO_JOIN,
 	NODE_ACSM_JOINING_STARTING_APPLICATIONS,
 	NODE_ACSM_JOINING_ASSIGNING_WORKLOAD
-} amf_node_acsm_state_t; 
+} amf_node_acsm_state_t;
 
 typedef enum {
 	SG_AC_Idle = 0,
@@ -243,7 +247,7 @@ typedef struct amf_fifo {
 
 
 typedef enum {
-	AMF_PRESENCE_TERMINATION_FAILED_REBOOT = 
+	AMF_PRESENCE_TERMINATION_FAILED_REBOOT =
 	SA_AMF_PRESENCE_TERMINATION_FAILED + 1
 } AmfPresenceStateT;
 
@@ -629,35 +633,35 @@ enum amf_message_req_types {
 };
 
 struct req_exec_amf_clc_cleanup_completed {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 	SaNameT compName;
 	int cleanup_exit_code;
 };
 
 struct req_exec_amf_healthcheck_tmo {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 	SaNameT compName;
 	SaAmfHealthcheckKeyT safHealthcheckKey;
 	SaAmfRecommendedRecoveryT recommendedRecovery;
 };
 
 struct req_exec_amf_comp_instantiate {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 	SaNameT compName;
 };
 
 struct req_exec_amf_comp_instantiate_tmo {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 	SaNameT compName;
 };
 
 struct req_exec_amf_comp_cleanup_tmo {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 	SaNameT compName;
 };
 
 struct req_exec_amf_cluster_start_tmo {
-	mar_req_header_t header;
+	coroipc_request_header_t header;
 	SaNameT sourceNodeName;
 };
 
@@ -669,7 +673,7 @@ extern void amf_runtime_attributes_print (struct amf_cluster *cluster);
 extern int amf_enabled (struct corosync_api_v1 *coroapi);
 extern void *_amf_malloc (size_t size, const char *file, unsigned int line);
 #define amf_malloc(size) _amf_malloc ((size), __FILE__, __LINE__)
-extern void *_amf_realloc (void* ptr, size_t size, const char *file, 
+extern void *_amf_realloc (void* ptr, size_t size, const char *file,
 	unsigned int line);
 #define amf_realloc(ptr,size) _amf_realloc ((ptr), (size), __FILE__, __LINE__)
 extern void *_amf_calloc (size_t nmemb, size_t size, const char *file,
@@ -702,7 +706,7 @@ extern char *amf_deserialize_SaUint32T (char *buf, SaUint32T *num);
 extern char *amf_deserialize_SaUint64T (char *buf, SaUint64T *num);
 extern char *amf_deserialize_opaque (char *buf, void *dst, int *cnt);
 extern int amf_msg_mcast (int msg_id, void *buf, size_t len);
-extern void amf_fifo_put (int entry_type, amf_fifo_t **root, 
+extern void amf_fifo_put (int entry_type, amf_fifo_t **root,
 	int size_of_data, void *data);
 extern int amf_fifo_get (amf_fifo_t **root, void *data);
 extern void amf_call_function_asynchronous (async_func_t async_func, void *param);
@@ -711,14 +715,14 @@ extern void amf_call_function_asynchronous (async_func_t async_func, void *param
 /* amfnode.c */
 
 /* General methods */
-extern struct amf_node *amf_node_new (struct amf_cluster *cluster, char *name);
+extern struct amf_node *amf_node_new (struct amf_cluster *cluster, const char *name);
 extern void *amf_node_serialize (struct amf_node *node, int *len);
 extern struct amf_node *amf_node_deserialize (
 	struct amf_cluster *cluster, char *buf);
 extern struct amf_node *amf_node_find (SaNameT *name);
 extern struct amf_node *amf_node_find_by_nodeid (unsigned int nodeid);
 extern struct amf_node *amf_node_find_by_hostname (const char *hostname);
-extern void amf_node_sg_failed_over (struct amf_node *node, 
+extern void amf_node_sg_failed_over (struct amf_node *node,
 	struct amf_sg *sg_in);
 
 /* Event methods */
@@ -764,12 +768,12 @@ extern int amf_cluster_applications_started_with_no_starting_sgs (
 
 
 /* Event methods */
-extern void amf_cluster_start_tmo_event (int is_sync_master, 
-	struct amf_cluster *cluster, SaNameT *sourceNodeName);
-extern void amf_cluster_sync_ready (struct amf_cluster *cluster, 
+extern void amf_cluster_start_tmo_event (int is_sync_master,
+	struct amf_cluster *cluster, const SaNameT *sourceNodeName);
+extern void amf_cluster_sync_ready (struct amf_cluster *cluster,
 	struct amf_node *node);
 /**
- * 
+ *
  * @param cluster
  * @param app
  */
@@ -815,7 +819,7 @@ extern void amf_application_sg_assigned (
 
 /* General methods */
 extern struct amf_sg *amf_sg_find (struct amf_application *app, char *name);
-extern struct amf_sg *amf_sg_new (struct amf_application *app, char *name);
+extern struct amf_sg *amf_sg_new (struct amf_application *app, const char *name);
 extern void amf_sg_delete (struct amf_sg *sg);
 extern void *amf_sg_serialize (struct amf_sg *sg, int *len);
 extern struct amf_sg *amf_sg_deserialize (
@@ -823,7 +827,7 @@ extern struct amf_sg *amf_sg_deserialize (
 
 /**
  * Request SG to start (instantiate all SUs)
- * 
+ *
  * @param sg
  * @param node - NULL start all SUs in the SG
  * @param node - !NULL start all SUs in the SG for the specified
@@ -862,7 +866,7 @@ extern void amf_sg_si_activated (
 /* General methods */
 extern struct amf_su *amf_su_find (
 	struct amf_cluster *cluster, SaNameT *name);
-extern struct amf_su *amf_su_new (struct amf_sg *sg, char *name);
+extern struct amf_su *amf_su_new (struct amf_sg *sg, const char *name);
 extern void amf_su_delete (struct amf_su *su);
 extern char *amf_su_dn_make (struct amf_su *su, SaNameT *name);
 extern void *amf_su_serialize (struct amf_su *su, int *len);
@@ -883,7 +887,7 @@ extern int amf_su_are_all_comps_in_su (struct amf_su *su,
 
 /* Event methods */
 /**
- * 
+ *
  * @param su
  * @param comp
  */
@@ -915,11 +919,11 @@ extern int amf_su_instantiate (struct amf_su *su);
 /* amfcomp.c */
 
 /* General methods */
-extern struct amf_comp *amf_comp_new (struct amf_su *su, char *name);
+extern struct amf_comp *amf_comp_new (struct amf_su *su, const char *name);
 extern void amf_comp_delete (struct amf_comp *comp);
 extern char *amf_comp_dn_make (struct amf_comp *comp, SaNameT *name);
 extern struct amf_comp *amf_comp_find (
-	struct amf_cluster *cluster, SaNameT *name);
+	struct amf_cluster *cluster, const SaNameT *name);
 extern void *amf_comp_serialize (struct amf_comp *comp, int *len);
 extern struct amf_comp *amf_comp_deserialize (
 	struct amf_su *su, char *buf);
@@ -957,7 +961,7 @@ extern void amf_comp_operational_state_set (
 extern void amf_comp_readiness_state_set (
 	struct amf_comp *comp, SaAmfReadinessStateT state);
 extern struct amf_healthcheck *amf_comp_find_healthcheck (
-	struct amf_comp *comp, SaAmfHealthcheckKeyT *key);
+	struct amf_comp *comp, const SaAmfHealthcheckKeyT *key);
 extern void amf_comp_healthcheck_tmo (
 	struct amf_comp *comp, SaAmfRecommendedRecoveryT recommendedRecovery);
 extern void amf_comp_cleanup_completed (struct amf_comp *comp);
@@ -966,7 +970,7 @@ extern void amf_comp_cleanup_failed_completed (amf_comp_t *comp);
 /**
  * Count number of active CSI assignments
  * @param component
- * 
+ *
  * @return int
  */
 extern int amf_comp_get_saAmfCompNumCurrActiveCsi(struct amf_comp *component);
@@ -974,23 +978,23 @@ extern int amf_comp_get_saAmfCompNumCurrActiveCsi(struct amf_comp *component);
 /**
  * Count number of standby CSI assignments
  * @param component
- * 
+ *
  * @return int
  */
 extern int amf_comp_get_saAmfCompNumCurrStandbyCsi(struct amf_comp *component);
 
 /*
- * Originates from library                                                                
+ * Originates from library
  */
 
 extern SaAisErrorT amf_comp_healthcheck_start (
 	struct amf_comp *comp,
-	SaAmfHealthcheckKeyT *healthcheckKey,
+	const SaAmfHealthcheckKeyT *healthcheckKey,
 	SaAmfHealthcheckInvocationT invocationType,
 	SaAmfRecommendedRecoveryT recommendedRecovery);
 extern SaAisErrorT amf_comp_healthcheck_stop (
 	struct amf_comp *comp,
-	SaAmfHealthcheckKeyT *healthcheckKey);
+	const SaAmfHealthcheckKeyT *healthcheckKey);
 extern SaAisErrorT amf_comp_pm_start (
 	struct amf_comp *comp,
 	SaUint64T pid,
@@ -1012,14 +1016,14 @@ extern int amf_comp_response_1 (
 	SaUint32T *interface, SaNameT *dn, SaAmfHealthcheckKeyT *healtcheck_key,
 	SaAmfRecommendedRecoveryT *recommendedRecovery);
 extern struct amf_comp *amf_comp_response_2 (
-	SaUint32T interface, SaNameT *dn, SaAmfHealthcheckKeyT *healthcheckKey,
-	SaAisErrorT error, SaAisErrorT *retval, 
+	SaUint32T interface, const SaNameT *dn, const SaAmfHealthcheckKeyT *healthcheckKey,
+	SaAisErrorT error, SaAisErrorT *retval,
 	SaAmfRecommendedRecoveryT recommendedRecovery);
 extern SaAisErrorT amf_comp_hastate_get (
-	struct amf_comp *comp, SaNameT *csi_name, SaAmfHAStateT *ha_state);
+	struct amf_comp *comp, const SaNameT *csi_name, SaAmfHAStateT *ha_state);
 extern SaAisErrorT amf_comp_healthcheck_confirm (
 	struct amf_comp *comp,
-	SaAmfHealthcheckKeyT *healthcheckKey,
+	const SaAmfHealthcheckKeyT *healthcheckKey,
 	SaAisErrorT healthcheckResult);
 
 extern amf_healthcheck_t *amf_healthcheck_new (struct amf_comp *comp);
@@ -1043,7 +1047,7 @@ extern void mcast_error_report_from_pm (
 
 /* General methods */
 extern struct amf_si *amf_si_find (struct amf_application *app, char *name);
-extern struct amf_si *amf_si_new (struct amf_application *app, char *name);
+extern struct amf_si *amf_si_new (struct amf_application *app, const char *name);
 extern void amf_si_delete (struct amf_si *si);
 extern int amf_si_calc_and_set_csi_dependency_level (struct amf_si *si);
 extern void *amf_si_serialize (struct amf_si *si, int *len);
@@ -1061,7 +1065,7 @@ char *amf_si_assignment_dn_make (struct amf_su *su, struct amf_si *si,
 /**
  * Get number of active assignments for the specified SI
  * @param si
- * 
+ *
  * @return int
  */
 extern int amf_si_get_saAmfSINumCurrActiveAssignments (struct amf_si *si);
@@ -1069,7 +1073,7 @@ extern int amf_si_get_saAmfSINumCurrActiveAssignments (struct amf_si *si);
  * Get number of active assignments for the specified SI and SU
  * @param si
  * @param su
- * 
+ *
  * @return int
  */
 extern int amf_si_su_get_saAmfSINumCurrActiveAssignments (struct amf_si *si,
@@ -1078,7 +1082,7 @@ extern int amf_si_su_get_saAmfSINumCurrActiveAssignments (struct amf_si *si,
 /**
  * Get number of standby assignments for the specified SI
  * @param si
- * 
+ *
  * @return int
  */
 
@@ -1087,7 +1091,7 @@ extern int amf_si_get_saAmfSINumCurrStandbyAssignments (struct amf_si *si);
 /**
  * Get number of standby assignments for the specified SI and SU
  * @param si
- * 
+ *
  * @return int
  */
 extern int amf_si_su_get_saAmfSINumCurrStandbyAssignments (struct amf_si *si,
@@ -1096,7 +1100,7 @@ extern int amf_si_su_get_saAmfSINumCurrStandbyAssignments (struct amf_si *si,
 /**
  * Get assignment state for the specified SI.
  * @param si
- * 
+ *
  * @return SaAmfAssignmentStateT
  */
 
@@ -1118,10 +1122,10 @@ extern void amf_si_activate (
 /**
  * Deactivate all active assignments. Request component to
  * change HA state to quiesced.
- * 
+ *
  * @param si_assignment
  * @param deactivated_callback_fn
- * 
+ *
  * @return int 1 - deactived immediately
  * @return int 0 - asynchronous response through callback
  */
@@ -1133,7 +1137,7 @@ extern int amf_si_deactivate (
 
 /**
  * Request SI (SU) to assume a HA state (request component)
- * 
+ *
  * @param si_assignment
  * @param assumed_ha_state_callback_fn
  */
@@ -1144,7 +1148,7 @@ extern void amf_si_ha_state_assume (
 
 /**
  * Component reports to SI that a workload assignment succeeded.
- * 
+ *
  * @param si
  * @param csi_assignment
  */
@@ -1168,7 +1172,7 @@ extern void amf_si_comp_csi_removed (
 
 /**
  * Request a CSI to delete all CSI assignments.
- * 
+ *
  * @param component
  * @param csi
  */
@@ -1176,7 +1180,7 @@ extern void amf_csi_delete_assignments (struct amf_csi *csi, struct amf_su *su);
 
 /* General methods */
 extern struct amf_csi *amf_csi_new (struct amf_si *si);
-extern struct amf_csi *amf_csi_find (struct amf_si *si, char *name);
+extern struct amf_csi *amf_csi_find (struct amf_si *si, const char *name);
 extern void amf_csi_delete (struct amf_csi *csi);
 extern void *amf_csi_serialize (struct amf_csi *csi, int *len);
 extern struct amf_csi *amf_csi_deserialize (
@@ -1189,23 +1193,20 @@ extern char *amf_csi_dn_make (struct amf_csi *csi, SaNameT *name);
 extern char *amf_csi_assignment_dn_make (
 	struct amf_csi_assignment *csi_assignment, SaNameT *name);
 extern struct amf_csi_assignment *amf_csi_assignment_find (
-	struct amf_cluster *cluster, SaNameT *name);
+	struct amf_cluster *cluster, const SaNameT *name);
 extern struct amf_csi_attribute *amf_csi_attribute_new (struct amf_csi *csi);
 extern void *amf_csi_attribute_serialize (
 	struct amf_csi_attribute *csi_attribute, int *len);
 extern struct amf_csi_attribute *amf_csi_attribute_deserialize (
 	struct amf_csi *csi, char *buf);
-/* extern int sa_amf_grep(const char *string, char *pattern, size_t nmatch, */
-/*	char** sub_match_array);                                             */
-
-extern int sa_amf_grep(const char *string, char *pattern, size_t nmatch,
+extern int sa_amf_grep(const char *string, const char *pattern, size_t nmatch,
 	SaNameT *sub_match_array);
 
 /*===========================================================================*/
 extern struct amf_node *this_amf_node;
 extern struct amf_cluster *amf_cluster;
 
-static inline int name_match(SaNameT *name1, SaNameT *name2)
+static inline int name_match(const SaNameT *name1, const SaNameT *name2)
 {
 	if (name1->length == name2->length) {
 		return ((strncmp ((char *)name1->value, (char *)name2->value, name1->length)) == 0);
@@ -1218,7 +1219,7 @@ static inline char *getSaNameT (SaNameT *name)
 	return ((char *)name->value);
 }
 
-static inline void setSaNameT (SaNameT *name, char *str) {
+static inline void setSaNameT (SaNameT *name, const char *str) {
 	strncpy ((char *)name->value, str, SA_MAX_NAME_LENGTH);
 	if (strlen ((char *)name->value) > SA_MAX_NAME_LENGTH) {
 		name->length = SA_MAX_NAME_LENGTH;
@@ -1227,5 +1228,20 @@ static inline void setSaNameT (SaNameT *name, char *str) {
 	}
 }
 
+extern void amfapp_init(void);
+
+extern void amfcluster_init(void);
+
+extern void amfcomp_init(void);
+
+extern void amfnode_init(void);
+
+extern void amfsg_init(void);
+
+extern void amfsi_init(void);
+
+extern void amfsu_init(void);
+
+extern void amfutil_init(void);
 
 #endif /* AMF_H_DEFINED */
