@@ -1,5 +1,5 @@
 /** @file amfcomp.c
- * 
+ *
  * Copyright (c) 2006 Ericsson AB.
  * Copyright (c) 2002-2006 MontaVista Software, Inc.
  * Copyright (c) 2006 Sun Microsystems, Inc. Copyright (c) 2006
@@ -18,7 +18,7 @@
  * - Serializers/deserializers
  *
  * This software licensed under BSD license, the text of which follows:
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
  *
@@ -42,15 +42,15 @@
  * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
  * THE POSSIBILITY OF SUCH DAMAGE.
- * 
+ *
  * AMF Component Class Implementation
- * 
- * This file contains functions for handling AMF-components. It can be 
+ *
+ * This file contains functions for handling AMF-components. It can be
  * viewed as the implementation of the AMF Component class (called comp)
- * as described in SAI-Overview-B.02.01. The SA Forum specification 
+ * as described in SAI-Overview-B.02.01. The SA Forum specification
  * SAI-AIS-AMF-B.02.01 has been used as specification of the behaviour
  * and is referred to as 'the spec' below.
- * 
+ *
  * The functions in this file are responsible for handling the following
  * types of components:
  * 	- sa-aware components
@@ -86,7 +86,7 @@
  * Comp initiates error reports to its parent SU in the cases described in
  * paragraph 3.3.2.2 in the spec. Comp delegates all actions to SU except
  *	- it stores the received or pre-configured recommended recovery
- *	  action 
+ *	  action
  *	- sets the operational state to DISABLED unless the
  *	  recommended recovery action was SA_AMF_COMP_RESTART. (In this case
  *	  SU or node may set operational state of the component later on
@@ -106,7 +106,7 @@
  * value of the ha-state but only to faciltate the communication of the CSI
  * set (or remove) order and to evaluate the response from the library.
  *
- * The presence state machine implements all the states described in the 
+ * The presence state machine implements all the states described in the
  * specification.
  * The '-ING' states of PRSM are designed as composite states (UML terminology).
  * Being a composite state means that the state contains substates.
@@ -120,9 +120,10 @@
  * 4.1 - 4.6 in the spec. The comp PRSM implements all the logic described
  * except for node reboot, which is handled by the AMF Node class.
  * Also PRSM reports all changes of state to its parent SU.
- * 
+ *
  */
 
+#include <config.h>
 
 #include <sys/types.h>
 #include <unistd.h>
@@ -134,10 +135,10 @@
 #include <assert.h>
 #include <dirent.h>
 #include <pthread.h>
+#include <inttypes.h>
 
 #include "amf.h"
 #include <netinet/in.h>
-#include <corosync/ipc_gen.h>
 #include "../include/ipc_amf.h"
 #include <corosync/engine/logsys.h>
 #include <corosync/engine/coroapi.h>
@@ -145,7 +146,7 @@
 #include "../include/saAis.h"
 #include "../include/saAmf.h"
 
-LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+LOGSYS_DECLARE_SUBSYS ("AMF");
 
 enum clc_command_run_operation_type {
 	CLC_COMMAND_RUN_OPERATION_TYPE_INSTANTIATE = 1,
@@ -192,7 +193,7 @@ static void lib_csi_set_request (
 	struct amf_comp *comp,
 	struct amf_csi_assignment *csi_assignment);
 
-static void comp_recover_action (amf_comp_t *comp, 
+static void comp_recover_action (amf_comp_t *comp,
 	SaAmfRecommendedRecoveryT recommendedRecovery);
 
 /*
@@ -235,6 +236,13 @@ struct invocation {
 	int active;
 };
 
+void amfcomp_init (void)
+{
+#ifdef OPENAIS_SOLARIS
+	logsys_subsys_init ();
+#endif
+}
+
 static struct invocation *invocation_entries = 0;
 static int invocation_entries_size = 0;
 
@@ -246,7 +254,7 @@ static int is_not_instantiating_or_instantiated_or_restarting (amf_comp_t *comp)
 }
 
 static int invocation_create (
-	int interface, 
+	int interface,
 	void *data)
 {
 	struct invocation *invocation_addr = 0;
@@ -311,7 +319,7 @@ static void invocation_destroy_by_data (void *data)
 
 /**
  * Set suspected error flag and report to SU.
- * 
+ *
  * @param comp
  * @param recommended_recovery
  */
@@ -332,7 +340,6 @@ static void *clc_command_run (void *context)
 {
 	struct clc_command_run_data *clc_command_run_data =
 		(struct clc_command_run_data *)context;
-	clc_command_run_data->exit_code = 0;
 
 	pid_t pid;
 	int res;
@@ -349,6 +356,8 @@ static void *clc_command_run (void *context)
 
 	ENTER();
 
+	clc_command_run_data->exit_code = 0;
+
 	pid = fork();
 
 	if (pid == -1) {
@@ -371,11 +380,11 @@ static void *clc_command_run (void *context)
 		if (WIFSIGNALED (status) != 0) {
 			fprintf (stderr, "Error: CLC_CLI (%d) failed with exit status:"
 				" %d\n", (int)pid, WTERMSIG(status));
-			/*                                                              
+			/*
 			 * TODO: remove this and handle properly later...
 			 */
 
-			/*                                                              
+			/*
 			 * Healthcheck timout will expire laterfore the component
 			 * and this will lead to Intantiation failed for the component.
 			 */
@@ -430,15 +439,17 @@ static void *clc_command_run (void *context)
 	argv = amf_malloc (sizeof (char*) * argv_size);
 	argv[0] = cmd;
 	{
+		char *ptrptr = NULL;
+		char *arg;
+
 		/* make a proper argv array */
 		i = 1;
-		char *ptrptr;
-		char *arg = strtok_r(comp_argv, " ", &ptrptr);
+		arg = strtok_r(comp_argv, " ", &ptrptr);
 		while (arg) {
 			argv_size++;
 			argv = realloc (argv, sizeof (char*) * argv_size);
 			if (argv == NULL) {
-				fprintf (stderr, "out-of-memory");  
+				fprintf (stderr, "out-of-memory");
 				corosync_fatal_error(COROSYNC_OUT_OF_MEMORY);
 			}
 			argv[i] = arg;
@@ -533,7 +544,7 @@ static void start_component_cleanup_timer (struct amf_comp *component)
 	}
 }
 
-void stop_component_cleanup_timer (struct amf_comp *component)
+static void stop_component_cleanup_timer (struct amf_comp *component)
 {
 	ENTER();
 
@@ -566,7 +577,7 @@ static int clc_cli_instantiate (struct amf_comp *comp)
 	res = pthread_create (&thread, &thread_attr, clc_command_run,
 		(void *)clc_command_run_data);
 	if (res != 0) {
-		log_printf (LOG_LEVEL_ERROR, "pthread_create failed: %d", res);
+		log_printf (LOGSYS_LEVEL_ERROR, "pthread_create failed: %d", res);
 	}
 	start_component_instantiate_timer (comp);
 	return (res);
@@ -596,7 +607,7 @@ static int clc_cli_terminate (struct amf_comp *comp)
 /**
  * Request component to terminate itself
  * @param comp
- * 
+ *
  * @return int
  */
 static int lib_comp_terminate_request (struct amf_comp *comp)
@@ -682,7 +693,7 @@ static int clc_cli_cleanup (struct amf_comp *comp)
 	res = pthread_create (&thread, &thread_attr, clc_command_run,
 		(void *)clc_command_run_data);
 	if (res != 0) {
-		log_printf (LOG_LEVEL_ERROR, "pthread_create failed: %d", res);
+		log_printf (LOGSYS_LEVEL_ERROR, "pthread_create failed: %d", res);
 	}
 // TODO error code from pthread_create
 	return (res);
@@ -721,7 +732,7 @@ char *amf_comp_dn_make (struct amf_comp *comp, SaNameT *name)
 }
 
 struct amf_healthcheck *amf_comp_find_healthcheck (
-	struct amf_comp *comp, SaAmfHealthcheckKeyT *key)
+	struct amf_comp *comp, const SaAmfHealthcheckKeyT *key)
 {
 	struct amf_healthcheck *healthcheck;
 	struct amf_healthcheck *ret_healthcheck = 0;
@@ -734,7 +745,7 @@ struct amf_healthcheck *amf_comp_find_healthcheck (
 		healthcheck != NULL;
 		healthcheck = healthcheck->next) {
 
-		if (key->keyLen == healthcheck->safHealthcheckKey.keyLen && 
+		if (key->keyLen == healthcheck->safHealthcheckKey.keyLen &&
 			memcmp (key, &healthcheck->safHealthcheckKey,key->keyLen) == 0) {
 			ret_healthcheck = healthcheck;
 			break;
@@ -751,10 +762,10 @@ struct amf_healthcheck *amf_comp_find_healthcheck (
  * here. Default values are initialized.
  * @param su
  * @param name
- * 
+ *
  * @return struct amf_comp*
  */
-struct amf_comp *amf_comp_new(struct amf_su *su, char *name)
+struct amf_comp *amf_comp_new(struct amf_su *su, const char *name)
 {
 	struct amf_comp *tail = su->comp_head;
 	struct amf_comp *comp = amf_calloc (1, sizeof (struct amf_comp));
@@ -843,7 +854,7 @@ end:
 	return comp;
 }
 
-struct amf_comp *amf_comp_find (struct amf_cluster *cluster, SaNameT *name)
+struct amf_comp *amf_comp_find (struct amf_cluster *cluster, const SaNameT *name)
 {
 	struct amf_application *app;
 	struct amf_sg *sg;
@@ -853,7 +864,7 @@ struct amf_comp *amf_comp_find (struct amf_cluster *cluster, SaNameT *name)
 	char *sg_name;
 	char *su_name;
 	char *comp_name;
-	char *ptrptr;
+	char *ptrptr = NULL;
 	char *buf;
 
 	assert (cluster != NULL && name != NULL);
@@ -890,7 +901,7 @@ struct amf_comp *amf_comp_find (struct amf_cluster *cluster, SaNameT *name)
 	for (su = sg->su_head; su != NULL; su = su->next) {
 		if (strncmp (su_name, (char*)su->name.value, su->name.length) == 0) {
 			for (comp = su->comp_head; comp != NULL; comp = comp->next) {
-				if (comp->name.length == strlen(comp_name) && 
+				if (comp->name.length == strlen(comp_name) &&
 					strncmp (comp_name, (char*)comp->name.value,
 					comp->name.length) == 0) {
 					goto end;
@@ -904,14 +915,15 @@ end:
 	return comp;
 }
 
-void amf_comp_healthcheck_deactivate (struct amf_comp *comp)
+#ifdef TODO
+static void amf_comp_healthcheck_deactivate (struct amf_comp *comp)
 {
 	struct amf_healthcheck *healthcheck;
 
 	if (!amf_su_is_local (comp->su))
 		return;
 
-	ENTER (); 
+	ENTER ();
 
 	for (healthcheck = comp->healthcheck_head;
 		healthcheck != NULL;
@@ -922,6 +934,7 @@ void amf_comp_healthcheck_deactivate (struct amf_comp *comp)
 		}
 	}
 }
+#endif
 
 static void comp_ha_state_set ( struct amf_comp *comp,
 	struct amf_csi_assignment *csi_assignment,
@@ -950,7 +963,7 @@ static void comp_presence_state_set (struct amf_comp *comp,
 
 struct amf_csi_assignment *amf_comp_get_next_csi_assignment (
 	struct amf_comp *component,
-	const struct amf_csi_assignment *csi_assignment) 
+	const struct amf_csi_assignment *csi_assignment)
 {
 	struct amf_si *si;
 	struct amf_csi *csi;
@@ -1026,7 +1039,7 @@ void amf_comp_foreach_csi_assignment (
 }
 
 static struct amf_csi_assignment *csi_assignment_find_in (
-	struct amf_comp *component, SaNameT *csi_name) 
+	struct amf_comp *component, const SaNameT *csi_name)
 {
 	struct amf_csi_assignment *csi_assignment;
 	SaNameT dn;
@@ -1087,10 +1100,10 @@ static void mcast_healthcheck_tmo_event (
 	struct req_exec_amf_healthcheck_tmo req_exec;
 	struct iovec iovec;
 	if (healthcheck->active == 0) {
-		log_printf (LOG_ERR, "Healthcheck timeout: ignored key = %s, "
+		log_printf (LOGSYS_LEVEL_ERROR, "Healthcheck timeout: ignored key = %s, "
 							 "due to wrong state = %d, comp = %s",
-			healthcheck->safHealthcheckKey.key, 
-			healthcheck->comp->saAmfCompPresenceState, 
+			healthcheck->safHealthcheckKey.key,
+			healthcheck->comp->saAmfCompPresenceState,
 			healthcheck->comp->name.value);
 		goto out;
 	}
@@ -1152,7 +1165,7 @@ static void lib_csi_set_request (
 	struct amf_comp *comp,
 	struct amf_csi_assignment *csi_assignment)
 {
-	struct res_lib_amf_csisetcallback* res_lib;     
+	struct res_lib_amf_csisetcallback* res_lib;
 	void*  p;
 	struct amf_csi_attribute *attribute;
 	size_t char_length_of_csi_attrs=0;
@@ -1201,17 +1214,17 @@ static void lib_csi_set_request (
 	}
 
 	res_lib->number = num_of_csi_attrs;
-	res_lib->csiFlags = SA_AMF_CSI_ADD_ONE;  
+	res_lib->csiFlags = SA_AMF_CSI_ADD_ONE;
 
 	switch (csi_assignment->requested_ha_state) {
 		case SA_AMF_HA_ACTIVE: {
 			res_lib->csiStateDescriptor.activeDescriptor.activeCompName.length = 0;
 			res_lib->csiStateDescriptor.activeDescriptor.transitionDescriptor =
-					SA_AMF_CSI_NEW_ASSIGN; 
+					SA_AMF_CSI_NEW_ASSIGN;
 			break;
 		}
 		case SA_AMF_HA_STANDBY: {
-			res_lib->csiStateDescriptor.standbyDescriptor.activeCompName.length = 0; 
+			res_lib->csiStateDescriptor.standbyDescriptor.activeCompName.length = 0;
 			res_lib->csiStateDescriptor.standbyDescriptor.standbyRank =  1;
 			break;
 		}
@@ -1224,13 +1237,13 @@ static void lib_csi_set_request (
 			break;
 		}
 		default: {
-			assert(SA_AMF_HA_ACTIVE||SA_AMF_HA_STANDBY||SA_AMF_HA_QUIESCING||SA_AMF_HA_QUIESCED);         
+			assert(SA_AMF_HA_ACTIVE||SA_AMF_HA_STANDBY||SA_AMF_HA_QUIESCING||SA_AMF_HA_QUIESCED);
 			break;
 		}
 	}
 
 	res_lib->header.id = MESSAGE_RES_AMF_CSISETCALLBACK;
-	res_lib->header.size = 
+	res_lib->header.size =
 		sizeof (struct res_lib_amf_csisetcallback) +
 		char_length_of_csi_attrs;
 	res_lib->header.error = SA_AIS_OK;
@@ -1243,7 +1256,7 @@ static void lib_csi_set_request (
 		invocation_create (AMF_RESPONSE_CSISETCALLBACK, csi_assignment);
 	api->ipc_dispatch_send (
 		comp->conn, res_lib, res_lib->header.size);
-	
+
 	free(p);
 }
 
@@ -1267,6 +1280,9 @@ SaAisErrorT amf_comp_register (struct amf_comp *comp)
 		case SA_AMF_PRESENCE_RESTARTING:
 			comp_presence_state_set (comp, SA_AMF_PRESENCE_INSTANTIATED);
 			break;
+		case SA_AMF_PRESENCE_UNINSTANTIATED:
+			/* wait until amf thinks it's instantitating */
+			return SA_AIS_ERR_TRY_AGAIN;
 		case SA_AMF_PRESENCE_INSTANTIATING:
 			amf_comp_operational_state_set (comp, SA_AMF_OPERATIONAL_ENABLED);
 			comp_presence_state_set (comp, SA_AMF_PRESENCE_INSTANTIATED);
@@ -1275,23 +1291,21 @@ SaAisErrorT amf_comp_register (struct amf_comp *comp)
             /* ignore due to instantitate timeout a while ago  */
 			break;
 		default:
-			log_printf(LOG_LEVEL_ERROR,"comp->saAmfCompPresenceState = %d",
+			log_printf(LOGSYS_LEVEL_ERROR,"comp->saAmfCompPresenceState = %d",
 				comp->saAmfCompPresenceState);
 			assert (0);
 			break;
-		
 	}
-	
 	return SA_AIS_OK;
 }
 
-void amf_comp_error_report (struct amf_comp *comp, amf_comp_t* reporting_comp, 
+void amf_comp_error_report (struct amf_comp *comp, amf_comp_t* reporting_comp,
 	SaAmfRecommendedRecoveryT recommendedRecovery)
 {
 	struct res_lib_amf_componenterrorreport res_lib;
 
 	if (reporting_comp != NULL) {
-		TRACE2("Exec comp error report on comp'%s' from %s", comp->name.value, 
+		TRACE2("Exec comp error report on comp'%s' from %s", comp->name.value,
 			   reporting_comp->name.value );
 
 		if (amf_su_is_local (reporting_comp->su)) {
@@ -1330,14 +1344,15 @@ static void clear_ha_state (
 }
 
 
-static void comp_recover_action (amf_comp_t *comp, 
+static void comp_recover_action (amf_comp_t *comp,
 	SaAmfRecommendedRecoveryT recommendedRecovery)
 {
+	amf_node_t *node;
 
 
 	ENTER ();
 
-	amf_node_t *node = amf_node_find (&comp->su->saAmfSUHostedByNode);
+	node = amf_node_find (&comp->su->saAmfSUHostedByNode);
 	switch (recommendedRecovery) {
 		case SA_AMF_NO_RECOMMENDATION: {
 			/*
@@ -1351,7 +1366,7 @@ static void comp_recover_action (amf_comp_t *comp,
 						amf_node_comp_failover_req (node, comp);
 					} else {
 						/* Component restart */
-						amf_su_comp_error_suspected (comp->su, comp, 
+						amf_su_comp_error_suspected (comp->su, comp,
 							recommendedRecovery);
 					}
 				case SA_AMF_COMPONENT_RESTART:
@@ -1360,7 +1375,7 @@ static void comp_recover_action (amf_comp_t *comp,
 						amf_node_comp_failover_req (node, comp);
 					} else {
 						/* Component restart */
-						amf_su_comp_error_suspected (comp->su, comp, 
+						amf_su_comp_error_suspected (comp->su, comp,
 							recommendedRecovery);
 					}
 					break;
@@ -1370,11 +1385,11 @@ static void comp_recover_action (amf_comp_t *comp,
 					break;
 				case SA_AMF_NODE_SWITCHOVER:
 					break;
-				case SA_AMF_NODE_FAILOVER: { 
+				case SA_AMF_NODE_FAILOVER: {
                     /* Node failover */
-					amf_node_t *node = amf_node_find (
+					amf_node_t *n = amf_node_find (
 						&comp->su->saAmfSUHostedByNode);
-					amf_node_failover(node);
+					amf_node_failover(n);
 				}
 				break;
 				case SA_AMF_NODE_FAILFAST:
@@ -1440,7 +1455,7 @@ void amf_comp_cleanup_completed (struct amf_comp *comp)
 {
 	TRACE2("Exec CLC cleanup completed for '%s' %d", comp->name.value,
 		comp->saAmfCompPresenceState);
-    
+
 	stop_component_cleanup_timer (comp);
 
 
@@ -1448,7 +1463,7 @@ void amf_comp_cleanup_completed (struct amf_comp *comp)
 	amf_comp_foreach_csi_assignment (comp, clear_ha_state);
 
 	amf_comp_error_suspected_clear (comp);
-	
+
 	if (comp->saAmfCompPresenceState == SA_AMF_PRESENCE_RESTARTING) {
 		amf_comp_instantiate (comp);
 	} else if (comp->saAmfCompPresenceState ==
@@ -1488,7 +1503,7 @@ static void timer_function_pm_fn (void *data)
 			free(pm);
 			continue;
 		}
-		sprintf(f,"/proc/%llu/stat", pm->pid);
+		sprintf(f,"/proc/%"PRIu64"/stat", pm->pid);
 		if (access( f, R_OK) != 0) {
 			if ((comp->su->restart_control_state != SU_RC_RESTART_SU_DEACTIVATING) &&
 				(comp->su->restart_control_state != SU_RC_RESTART_SU_TERMINATING) &&
@@ -1497,7 +1512,7 @@ static void timer_function_pm_fn (void *data)
 				/* don't report it as an error if we are busy
 				 * shutting down
 				 */
-				syslog(LOG_ALERT, "component %s:%s exited",
+				syslog(LOGSYS_LEVEL_ALERT, "component %s:%s exited",
 					   comp->su->saAmfSUHostedByNode.value, comp->name.value);
 				mcast_error_report_from_pm (comp, pm->recovery);
 				reported = SA_TRUE;
@@ -1518,7 +1533,7 @@ static void timer_function_pm_fn (void *data)
 }
 
 /**
- * Find and add all children of a given PID 
+ * Find and add all children of a given PID
  * @param comp the component
  * @param pmErrors the errors to monitor
  * @param recommendedRecovery
@@ -1527,7 +1542,7 @@ static void timer_function_pm_fn (void *data)
  * @param ppid the process id to find children of
  * @param depth the descendents tree depth to monitor
  */
-void amf_comp_find_and_add_child_pids(
+static void amf_comp_find_and_add_child_pids(
 	struct amf_comp *comp,
 	SaAmfPmErrorsT pmErrors,
 	SaAmfRecommendedRecoveryT recommendedRecovery,
@@ -1552,7 +1567,7 @@ void amf_comp_find_and_add_child_pids(
 		if (p == NULL)
 			continue;
 
-		res = fscanf(p, "%llu %*s %*c %llu", &p_id, &parent);
+		res = fscanf(p, "%"PRIu64" %*s %*c %"PRIu64, &p_id, &parent);
 
 		if ((res == 2) && (parent == ppid)) {
 
@@ -1562,7 +1577,7 @@ void amf_comp_find_and_add_child_pids(
 				return;
 			}
 
-			TRACE2 ("add child (pid=%llu) for comp pid=%llu (%s)\n", p_id, ppid, comp->name.value);
+			TRACE2 ("add child (pid=%"PRIu64") for comp pid=%"PRIu64" (%s)\n", p_id, ppid, comp->name.value);
 
 			pm->pid = p_id;
 			pm->errors = pmErrors;
@@ -1609,7 +1624,7 @@ SaAisErrorT amf_comp_pm_start (
 	SaInt32T numProcEntriesFound;
 
 	if (is_not_instantiating_or_instantiated_or_restarting (comp)) {
-		log_printf (LOG_ERR, "PmStart: ignored due to wrong state = %d, comp = %s",
+		log_printf (LOGSYS_LEVEL_ERROR, "PmStart: ignored due to wrong state = %d, comp = %s",
 					comp->saAmfCompPresenceState, comp->name.value);
 		return SA_AIS_ERR_FAILED_OPERATION;
 	}
@@ -1716,35 +1731,35 @@ SaAisErrorT amf_comp_pm_stop (
 
 /**
  * Handle the request from a component to start a healthcheck
- * 
+ *
  * @param comp
  * @param healthcheckKey
  * @param invocationType
  * @param recommendedRecovery
- * 
+ *
  * @return SaAisErrorT - return value to component
  */
 SaAisErrorT amf_comp_healthcheck_start (
 	struct amf_comp *comp,
-	SaAmfHealthcheckKeyT *healthcheckKey,
+	const SaAmfHealthcheckKeyT *healthcheckKey,
 	SaAmfHealthcheckInvocationT invocationType,
 	SaAmfRecommendedRecoveryT recommendedRecovery)
 {
 	struct amf_healthcheck *healthcheck;
 	SaAisErrorT error = SA_AIS_OK;
-	
+
 	if (is_not_instantiating_or_instantiated_or_restarting (comp)) {
-		log_printf (LOG_ERR, "Healthcheckstart: ignored key = %s, "
+		log_printf (LOGSYS_LEVEL_ERROR, "Healthcheckstart: ignored key = %s, "
 							 "due to wrong state = %d, comp = %s",
 			healthcheckKey->key, comp->saAmfCompPresenceState, comp->name.value);
 		error = SA_AIS_OK;
-		goto error_exit;	
+		goto error_exit;
 	}
-		
+
 
 	healthcheck = amf_comp_find_healthcheck (comp, healthcheckKey);
 	if (healthcheck == 0) {
-		log_printf (LOG_ERR, "Healthcheckstart: Healthcheck '%s' not found",
+		log_printf (LOGSYS_LEVEL_ERROR, "Healthcheckstart: Healthcheck '%s' not found",
 			healthcheckKey->key);
 		error = SA_AIS_ERR_NOT_EXIST;
 		goto error_exit;
@@ -1796,18 +1811,18 @@ error_exit:
  * Stop all or a specifed healthcheck
  * @param comp
  * @param healthcheckKey - NULL if all
- * 
+ *
  * @return SaAisErrorT
  */
 SaAisErrorT amf_comp_healthcheck_stop (
 	struct amf_comp *comp,
-	SaAmfHealthcheckKeyT *healthcheckKey)
+	const SaAmfHealthcheckKeyT *healthcheckKey)
 {
 	struct amf_healthcheck *healthcheck;
 	SaAisErrorT error = SA_AIS_OK;
 
 	TRACE1 ("Healthcheckstop: '%s'", comp->name.value);
- 
+
 	if (!amf_su_is_local (comp->su)) {
 		return SA_AIS_OK;
 	}
@@ -1821,7 +1836,7 @@ SaAisErrorT amf_comp_healthcheck_stop (
 	} else {
 		healthcheck = amf_comp_find_healthcheck (comp, healthcheckKey);
 		if (healthcheck == NULL) {
-			log_printf (LOG_ERR, "Healthcheckstop: Healthcheck '%s' not found",
+			log_printf (LOGSYS_LEVEL_ERROR, "Healthcheckstop: Healthcheck '%s' not found",
 				healthcheckKey->key);
 			error = SA_AIS_ERR_NOT_EXIST;
 		} else {
@@ -1838,6 +1853,8 @@ SaAisErrorT amf_comp_healthcheck_stop (
  */
 void amf_comp_instantiate (struct amf_comp *comp)
 {
+	SaNameT compName;
+
 	ENTER ();
 
 	switch (comp->saAmfCompPresenceState) {
@@ -1845,16 +1862,15 @@ void amf_comp_instantiate (struct amf_comp *comp)
 			/* fall through */
 		case SA_AMF_PRESENCE_UNINSTANTIATED:
 			if (amf_su_is_local (comp->su)) {
-				TRACE1("Send instantiate event for comp '%s' from host %s", 
+				TRACE1("Send instantiate event for comp '%s' from host %s",
 					comp->name.value, comp->su->saAmfSUHostedByNode.value);
-				SaNameT compName;
 				amf_comp_dn_make (comp, &compName);
 				amf_msg_mcast (MESSAGE_REQ_EXEC_AMF_COMPONENT_INSTANTIATE,
 					&compName, sizeof (SaNameT));
 			}
 			break;
 		default:
-			TRACE1("Instantiate ignored in Component presence state %d", 
+			TRACE1("Instantiate ignored in Component presence state %d",
 				comp->saAmfCompPresenceState);
 			break;
 	}
@@ -1863,7 +1879,7 @@ void amf_comp_instantiate (struct amf_comp *comp)
 void amf_comp_cleanup_tmo_event (struct amf_comp *comp)
 {
 	ENTER ();
-	amf_comp_error_suspected_clear(comp);	
+	amf_comp_error_suspected_clear(comp);
 	amf_comp_operational_state_set (comp, SA_AMF_OPERATIONAL_DISABLED);
 	comp_presence_state_set (comp, SA_AMF_PRESENCE_TERMINATION_FAILED);
 }
@@ -1903,13 +1919,13 @@ void amf_comp_instantiate_event (struct amf_comp *component)
 		case SA_AMF_PRESENCE_TERMINATING:
 		case SA_AMF_PRESENCE_INSTANTIATION_FAILED:
 		case SA_AMF_PRESENCE_TERMINATION_FAILED:
-			TRACE1("Instantiate ignored in Component presence state %d", 
+			TRACE1("Instantiate ignored in Component presence state %d",
 				component->saAmfCompPresenceState);
 			break;
 		case SA_AMF_PRESENCE_UNINSTANTIATED:
 
 			comp_presence_state_set (component, SA_AMF_PRESENCE_INSTANTIATING);
-			amf_su_comp_state_changed(component->su, 
+			amf_su_comp_state_changed(component->su,
 				component,SA_AMF_PRESENCE_STATE,SA_AMF_PRESENCE_INSTANTIATING);
 			if (amf_su_is_local (component->su)) {
 				res = clc_interfaces[component->comptype]->instantiate (
@@ -1924,7 +1940,7 @@ void amf_comp_instantiate_event (struct amf_comp *component)
 			}
 			break;
 		default:
-			TRACE1("Component presence state %d", 
+			TRACE1("Component presence state %d",
 				component->saAmfCompPresenceState);
 			assert (0);
 			break;
@@ -1944,7 +1960,7 @@ void amf_comp_readiness_state_set (struct amf_comp *comp,
  * @param invocation [in] associates the response with the request (callback)
  * @param error [in] response from the component of the associated callback
  * @param retval [out] contains return value to component when needed
- * 
+ *
  * @return ==0 respond to component, do not multicast
  * @return >0  do not respond to component, multicast response
  */
@@ -1959,7 +1975,7 @@ int amf_comp_response_1 (
 	res = invocation_get_and_destroy (invocation, interface, &data);
 
 	if (res == -1) {
-		log_printf (LOG_ERR, "Lib response: invocation not found\n");
+		log_printf (LOGSYS_LEVEL_ERROR, "Lib response: invocation not found\n");
 		*retval = SA_AIS_ERR_INVALID_PARAM;
 		return 0;
 	}
@@ -1978,15 +1994,15 @@ int amf_comp_response_1 (
 					sizeof (SaAmfHealthcheckKeyT));
 				*recommendedRecovery = healthcheck->recommendedRecovery;
 
-				if (error != SA_AIS_OK && 
+				if (error != SA_AIS_OK &&
 					!amf_comp_is_error_suspected (healthcheck->comp)) {
-					return 1; 
+					return 1;
 				}
 				if (is_not_instantiating_or_instantiated_or_restarting(
 					healthcheck->comp)) {
-					log_printf (LOG_ERR, "HealthcheckResponse: ignored for key = %s, "
+					log_printf (LOGSYS_LEVEL_ERROR, "HealthcheckResponse: ignored for key = %s, "
 										 "due to wrong state = %d comp = %s",
-						healthcheck->safHealthcheckKey.key, 
+						healthcheck->safHealthcheckKey.key,
 						healthcheck->comp->saAmfCompPresenceState,
 						healthcheck->comp->name.value);
 					*retval = SA_AIS_OK;
@@ -2046,15 +2062,16 @@ int amf_comp_response_1 (
  * @param invocation [in] associates the response with the request (callback)
  * @param error [in] response from the component of the associated callback
  * @param retval [out] contains return value to component when needed
- * 
+ *
  * @return component to which the response should be sent
  */
-struct amf_comp *amf_comp_response_2 (SaUint32T interface, SaNameT *dn, 
-	SaAmfHealthcheckKeyT *healthcheck_key, SaAisErrorT error, 
+struct amf_comp *amf_comp_response_2 (SaUint32T interface, const SaNameT *dn,
+	const SaAmfHealthcheckKeyT *healthcheck_key, SaAisErrorT error,
 	SaAisErrorT *retval, SaAmfRecommendedRecoveryT recommendedRecovery)
 {
 	struct amf_csi_assignment *csi_assignment;
 	struct amf_comp *comp = NULL;
+	amf_healthcheck_t *healthcheck;
 
 	assert (retval != NULL);
 
@@ -2100,14 +2117,14 @@ struct amf_comp *amf_comp_response_2 (SaUint32T interface, SaNameT *dn,
 		case AMF_RESPONSE_HEALTHCHECKCALLBACK: {
 			TRACE1("AMF_RESPONSE_HEALTHCHECKCALLBACK for %s", dn->value);
 			comp = amf_comp_find (amf_cluster, dn);
-			
+
 			assert (comp);
-			amf_healthcheck_t *healthcheck = amf_comp_find_healthcheck (
+			healthcheck = amf_comp_find_healthcheck (
 				comp, healthcheck_key);
 			assert (comp);
-			healthcheck->recommendedRecovery = recommendedRecovery; 
+			healthcheck->recommendedRecovery = recommendedRecovery;
 			comp_recover_action (comp, healthcheck->recommendedRecovery);
-				
+
 			break;
 		}
 
@@ -2140,7 +2157,7 @@ void amf_comp_hastate_set (
 	struct amf_csi_assignment *csi_assignment)
 {
 	ENTER ();
-	
+
 	assert (component != NULL && csi_assignment != NULL);
 
 
@@ -2150,7 +2167,7 @@ void amf_comp_hastate_set (
 		if (csi_assignment->requested_ha_state == SA_AMF_HA_QUIESCED) {
 			csi_assignment->saAmfCSICompHAState = csi_assignment->requested_ha_state;
 		} else {
-			TRACE1 ("csi_assignment->requested_ha_state = %d", 
+			TRACE1 ("csi_assignment->requested_ha_state = %d",
 				component->error_suspected);
 			assert (0);
 		}
@@ -2203,11 +2220,11 @@ void amf_comp_restart (struct amf_comp *comp)
  * @param comp
  * @param csi_name
  * @param ha_state
- * 
+ *
  * @return SaAisErrorT
  */
 SaAisErrorT amf_comp_hastate_get (
-	struct amf_comp *comp, SaNameT *csi_name, SaAmfHAStateT *ha_state)
+	struct amf_comp *comp, const SaNameT *csi_name, SaAmfHAStateT *ha_state)
 {
 	struct amf_csi_assignment *assignment;
 
@@ -2230,12 +2247,12 @@ SaAisErrorT amf_comp_hastate_get (
  * @param comp
  * @param healthcheckKey
  * @param healthcheckResult
- * 
+ *
  * @return SaAisErrorT
  */
 SaAisErrorT amf_comp_healthcheck_confirm (
 	struct amf_comp *comp,
-	SaAmfHealthcheckKeyT *healthcheckKey,
+	const SaAmfHealthcheckKeyT *healthcheckKey,
 	SaAisErrorT healthcheckResult)
 {
 	struct amf_healthcheck *healthcheck;
@@ -2243,14 +2260,14 @@ SaAisErrorT amf_comp_healthcheck_confirm (
 
 	healthcheck = amf_comp_find_healthcheck (comp, healthcheckKey);
 	if (is_not_instantiating_or_instantiated_or_restarting(comp)) {
-		log_printf (LOG_ERR, "HealthcheckConfirm: ignored for key = %s, "
+		log_printf (LOGSYS_LEVEL_ERROR, "HealthcheckConfirm: ignored for key = %s, "
 							 "due to wrong state = %d, comp = %s",
 			healthcheckKey->key, comp->saAmfCompPresenceState, comp->name.value);
 		error = SA_AIS_OK;
 		goto out;
 	}
 	if (healthcheck == NULL) {
-		log_printf (LOG_ERR, "Healthcheckstop: Healthcheck '%s' not found",
+		log_printf (LOGSYS_LEVEL_ERROR, "Healthcheckstop: Healthcheck '%s' not found",
 			healthcheckKey->key);
 		error = SA_AIS_ERR_NOT_EXIST;
 	} else if (healthcheck->active) {
@@ -2348,7 +2365,7 @@ SaAmfReadinessStateT amf_comp_get_saAmfCompReadinessState (
  * reporting the new state is uninstantiated while pending csi
  * operations are indicated by 'operation failed'.
  * @param comp
- * 
+ *
  * @return void
  */
 void amf_comp_node_left (struct amf_comp *component)
@@ -2396,7 +2413,7 @@ void amf_comp_node_left (struct amf_comp *component)
 
 	csi_assignment = amf_comp_get_next_csi_assignment (component, NULL);
 	while (csi_assignment != NULL) {
-		if (csi_assignment->requested_ha_state != 
+		if (csi_assignment->requested_ha_state !=
 			csi_assignment->saAmfCSICompHAState) {
 			amf_si_comp_set_ha_state_failed (
 				csi_assignment->csi->si,csi_assignment);
@@ -2412,7 +2429,7 @@ void amf_comp_node_left (struct amf_comp *component)
  * caller.
  * @param component
  * @param len
- * 
+ *
  * @return void*
  */
 void *amf_comp_serialize (struct amf_comp *component, int *len)
@@ -2540,7 +2557,7 @@ void *amf_comp_serialize (struct amf_comp *component, int *len)
  * @param su
  * @param buf
  * @param size
- * 
+ *
  * @return struct amf_comp*
  */
 struct amf_comp *amf_comp_deserialize (struct amf_su *su, char *buf)
@@ -2548,7 +2565,9 @@ struct amf_comp *amf_comp_deserialize (struct amf_su *su, char *buf)
 	char *tmp = buf;
 	int i;
 	SaUint32T cnt;
-	struct amf_comp *component = amf_comp_new (su, "");
+	struct amf_comp *component;
+
+	component = amf_comp_new (su, "");
 
 	tmp = amf_deserialize_SaNameT (tmp, &component->name);
 	tmp = amf_deserialize_SaUint32T (tmp, &cnt);
@@ -2737,4 +2756,3 @@ int amf_comp_is_error_suspected (amf_comp_t *comp)
 {
 	return comp->error_suspected ? 1 : 0;
 }
-
