@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008 Red Hat, Inc.
+ * Copyright (c) 2008, 2009 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -32,6 +32,8 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <config.h>
+
 #include <sys/types.h>
 #include <sys/uio.h>
 #include <sys/socket.h>
@@ -43,13 +45,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
-#include <signal.h>
 #include <time.h>
 #include <arpa/inet.h>
 
 #include <inttypes.h>
 
-#include <corosync/ipc_gen.h>
+#include <corosync/corotypes.h>
+#include <corosync/coroipc_types.h>
+#include <corosync/coroipcc.h>
+#include <corosync/corodefs.h>
 #include <corosync/mar_gen.h>
 #include <corosync/swab.h>
 #include <corosync/list.h>
@@ -62,7 +66,7 @@
 #include "../include/saTmr.h"
 #include "../include/ipc_tmr.h"
 
-LOGSYS_DECLARE_SUBSYS ("TMR", LOG_INFO);
+LOGSYS_DECLARE_SUBSYS ("TMR");
 
 struct timer_instance {
 	SaTmrTimerIdT timer_id;
@@ -76,12 +80,7 @@ struct timer_instance {
 	struct list_head cleanup_list;
 };
 
-static struct hdb_handle_database timer_hdb = {
-	.handle_count	= 0,
-	.handles	= 0,
-	.iterator	= 0,
-	.mutex		= PTHREAD_MUTEX_INITIALIZER
-};
+DECLARE_HDB_DATABASE (timer_hdb,NULL);
 
 static struct corosync_api_v1 *api;
 
@@ -91,35 +90,35 @@ static int tmr_lib_exit_fn (void *conn);
 
 static void message_handler_req_lib_tmr_timerstart (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_timerreschedule (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_timercancel (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_periodictimerskip (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_timerremainingtimeget (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_timerattributesget (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_timeget (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static void message_handler_req_lib_tmr_clocktickget (
 	void *conn,
-	void *msg);
+	const void *msg);
 
 static struct corosync_api_v1 *api;
 
@@ -132,50 +131,34 @@ static struct corosync_lib_handler tmr_lib_engine[] =
 {
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_timerstart,
-		.response_size		= sizeof (struct req_lib_tmr_timerstart),
-		.response_id		= MESSAGE_RES_TMR_TIMERSTART,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_timerreschedule,
-		.response_size		= sizeof (struct req_lib_tmr_timerreschedule),
-		.response_id		= MESSAGE_RES_TMR_TIMERRESCHEDULE,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_timercancel,
-		.response_size		= sizeof (struct req_lib_tmr_timercancel),
-		.response_id		= MESSAGE_RES_TMR_TIMERCANCEL,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_periodictimerskip,
-		.response_size		= sizeof (struct req_lib_tmr_periodictimerskip),
-		.response_id		= MESSAGE_RES_TMR_PERIODICTIMERSKIP,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_timerremainingtimeget,
-		.response_size		= sizeof (struct req_lib_tmr_timerremainingtimeget),
-		.response_id		= MESSAGE_RES_TMR_TIMERREMAININGTIMEGET,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_timerattributesget,
-		.response_size		= sizeof (struct req_lib_tmr_timerattributesget),
-		.response_id		= MESSAGE_RES_TMR_TIMERATTRIBUTESGET,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_timeget,
-		.response_size		= sizeof (struct req_lib_tmr_timeget),
-		.response_id		= MESSAGE_RES_TMR_TIMEGET,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 	{
 		.lib_handler_fn		= message_handler_req_lib_tmr_clocktickget,
-		.response_size		= sizeof (struct req_lib_tmr_clocktickget),
-		.response_id		= MESSAGE_RES_TMR_CLOCKTICKGET,
 		.flow_control		= COROSYNC_LIB_FLOW_CONTROL_REQUIRED
 	},
 };
@@ -194,6 +177,7 @@ struct corosync_service_engine tmr_service_engine = {
 	.exec_engine		= NULL,
 	.exec_engine_count	= 0,
 	.confchg_fn		= NULL,
+	.sync_mode		= CS_SYNC_V2,
 	.sync_init		= NULL,
 	.sync_process		= NULL,
 	.sync_activate		= NULL,
@@ -230,13 +214,25 @@ static struct corosync_service_engine *tmr_get_engine_ver0 (void)
 	return (&tmr_service_engine);
 }
 
-__attribute__ ((constructor)) static void register_this_component (void) {
+#ifdef OPENAIS_SOLARIS
+void corosync_lcr_component_register (void);
+
+void corosync_lcr_component_register (void)
+{
+#else
+__attribute__ ((constructor)) static void corosync_lcr_component_register (void)
+{
+#endif
 	lcr_interfaces_set (&openais_tmr_ver0[0], &tmr_service_engine_iface);
 	lcr_component_register (&tmr_comp_ver0);
 }
 
 static int tmr_exec_init_fn (struct corosync_api_v1 *corosync_api)
 {
+#ifdef OPENAIS_SOLARIS
+	logsys_subsys_init();
+#endif
+
 	api = corosync_api;
 
 	return (0);
@@ -265,7 +261,7 @@ static int tmr_lib_exit_fn (void *conn)
 		timer_instance = list_entry (cleanup_list, struct timer_instance, cleanup_list);
 
 		/* DEBUG */
-		log_printf (LOG_LEVEL_NOTICE, "[DEBUG]: cleanup timer { id=%u }\n",
+		log_printf (LOGSYS_LEVEL_DEBUG, "[DEBUG]: cleanup timer { id=0x%04x }\n",
 			    (unsigned int)(timer_instance->timer_id));
 
 		api->timer_delete (timer_instance->timer_handle);
@@ -289,7 +285,7 @@ static void tmr_timer_expired (void *data)
 	timer_instance->expiration_count += 1;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "[DEBUG]: tmr_timer_expired { id=%u }\n",
+	log_printf (LOGSYS_LEVEL_DEBUG, "[DEBUG]: tmr_timer_expired { id=0x%04x }\n",
 		    (unsigned int)(timer_instance->timer_id));
 
 	res_lib_tmr_timerexpiredcallback.header.size =
@@ -310,7 +306,7 @@ static void tmr_timer_expired (void *data)
 	}
 	else {
 		/* DEBUG */
-		log_printf (LOG_LEVEL_NOTICE, "[DEBUG]: skipping timer { id=%u }\n",
+		log_printf (LOGSYS_LEVEL_DEBUG, "[DEBUG]: skipping timer { id=0x%04x }\n",
 			    (unsigned int)(timer_instance->timer_id));
 
 		timer_instance->timer_skip -= 1;
@@ -345,7 +341,7 @@ static void tmr_timer_expired (void *data)
 
 static void message_handler_req_lib_tmr_timerstart (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
 	struct req_lib_tmr_timerstart *req_lib_tmr_timerstart =
 		(struct req_lib_tmr_timerstart *)msg;
@@ -353,11 +349,11 @@ static void message_handler_req_lib_tmr_timerstart (
 	struct timer_instance *timer_instance = NULL;
 	SaAisErrorT error = SA_AIS_OK;
 
-	hdb_handle_t timer_id;
+	hdb_handle_t timer_id = 0;
 	struct tmr_pd *tmr_pd = (struct tmr_pd *) api->ipc_private_data_get (conn);
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrTimerStart\n");
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrTimerStart\n");
 
 	hdb_handle_create (&timer_hdb,
 		   sizeof (struct timer_instance),
@@ -374,10 +370,6 @@ static void message_handler_req_lib_tmr_timerstart (
 	timer_instance->timer_id = timer_id;
 	timer_instance->timer_data = req_lib_tmr_timerstart->timer_data;
 
-	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "[DEBUG]:\t timer_data=%p\n",
-		    (void *)(timer_instance->timer_data));
-
 	memcpy (&timer_instance->timer_attributes,
 		&req_lib_tmr_timerstart->timer_attributes,
 		sizeof (SaTmrTimerAttributesT));
@@ -427,31 +419,54 @@ error_exit:
 
 static void message_handler_req_lib_tmr_timerreschedule (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
 	struct req_lib_tmr_timerreschedule *req_lib_tmr_timerreschedule =
 		(struct req_lib_tmr_timerreschedule *)msg;
 	struct res_lib_tmr_timerreschedule res_lib_tmr_timerreschedule;
 	struct timer_instance *timer_instance = NULL;
 	SaAisErrorT error = SA_AIS_OK;
+	SaTimeT current_time = 0;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrTimerReschedule { id=%u }\n",
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrTimerReschedule { id=0x%04x }\n",
 		    (unsigned int)(req_lib_tmr_timerreschedule->timer_id));
 
 	hdb_handle_get (&timer_hdb,
-		(unsigned int)(req_lib_tmr_timerreschedule->timer_id),
+		(hdb_handle_t)(req_lib_tmr_timerreschedule->timer_id),
 		(void *)&timer_instance);
 	if (timer_instance == NULL) {
 		error = SA_AIS_ERR_NOT_EXIST;
 		goto error_exit;
 	}
 
+	current_time = (SaTimeT)(api->timer_time_get());
+
+	if (current_time > req_lib_tmr_timerreschedule->timer_attributes.initialExpirationTime) {
+		error = SA_AIS_ERR_INVALID_PARAM;
+		goto error_put;
+	}
+
+	if (timer_instance->timer_attributes.timerPeriodDuration != 0) {
+		if (req_lib_tmr_timerreschedule->timer_attributes.timerPeriodDuration <= 0) {
+			error = SA_AIS_ERR_INVALID_PARAM;
+			goto error_put;
+		}
+	}
+	else {
+		if (req_lib_tmr_timerreschedule->timer_attributes.timerPeriodDuration != 0) {
+			error = SA_AIS_ERR_INVALID_PARAM;
+			goto error_put;
+		}
+	}
+
 	memcpy (&timer_instance->timer_attributes,
 		&req_lib_tmr_timerreschedule->timer_attributes,
 		sizeof (SaTmrTimerAttributesT));
 
-	hdb_handle_put (&timer_hdb, (unsigned int)(timer_instance->timer_id));
+error_put:
+
+	hdb_handle_put (&timer_hdb, (hdb_handle_t)(timer_instance->timer_id));
 
 error_exit:
 
@@ -468,7 +483,7 @@ error_exit:
 
 static void message_handler_req_lib_tmr_timercancel (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
 	struct req_lib_tmr_timercancel *req_lib_tmr_timercancel =
 		(struct req_lib_tmr_timercancel *)msg;
@@ -477,11 +492,11 @@ static void message_handler_req_lib_tmr_timercancel (
 	SaAisErrorT error = SA_AIS_OK;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrTimerCancel { id=%u }\n",
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrTimerCancel { id=0x%04x }\n",
 		    (unsigned int)(req_lib_tmr_timercancel->timer_id));
 
 	hdb_handle_get (&timer_hdb,
-		(unsigned int)(req_lib_tmr_timercancel->timer_id),
+		(hdb_handle_t)(req_lib_tmr_timercancel->timer_id),
 		(void *)&timer_instance);
 	if (timer_instance == NULL) {
 		error = SA_AIS_ERR_NOT_EXIST;
@@ -494,8 +509,8 @@ static void message_handler_req_lib_tmr_timercancel (
 
 	list_del (&timer_instance->cleanup_list);
 
-	hdb_handle_destroy (&timer_hdb, (unsigned int)(timer_instance->timer_id));
-	hdb_handle_put (&timer_hdb, (unsigned int)(timer_instance->timer_id));
+	hdb_handle_destroy (&timer_hdb, (hdb_handle_t)(timer_instance->timer_id));
+	hdb_handle_put (&timer_hdb, (hdb_handle_t)(timer_instance->timer_id));
 
 error_exit:
 
@@ -512,7 +527,7 @@ error_exit:
 
 static void message_handler_req_lib_tmr_periodictimerskip (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
 	struct req_lib_tmr_periodictimerskip *req_lib_tmr_periodictimerskip =
 		(struct req_lib_tmr_periodictimerskip *)msg;
@@ -521,11 +536,11 @@ static void message_handler_req_lib_tmr_periodictimerskip (
 	SaAisErrorT error = SA_AIS_OK;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrPeriodicTimerSkip { id=%u }\n",
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrPeriodicTimerSkip { id=0x%04x }\n",
 		    (unsigned int)(req_lib_tmr_periodictimerskip->timer_id));
 
 	hdb_handle_get (&timer_hdb,
-		(unsigned int)(req_lib_tmr_periodictimerskip->timer_id),
+		(hdb_handle_t)(req_lib_tmr_periodictimerskip->timer_id),
 		(void *)&timer_instance);
 	if (timer_instance == NULL) {
 		error = SA_AIS_ERR_NOT_EXIST;
@@ -539,7 +554,7 @@ static void message_handler_req_lib_tmr_periodictimerskip (
 
 	timer_instance->timer_skip += 1;
 
-	hdb_handle_put (&timer_hdb, (unsigned int)(timer_instance->timer_id));
+	hdb_handle_put (&timer_hdb, (hdb_handle_t)(timer_instance->timer_id));
 
 error_exit:
 
@@ -556,7 +571,7 @@ error_exit:
 
 static void message_handler_req_lib_tmr_timerremainingtimeget (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
 	struct req_lib_tmr_timerremainingtimeget *req_lib_tmr_timerremainingtimeget =
 		(struct req_lib_tmr_timerremainingtimeget *)msg;
@@ -565,11 +580,11 @@ static void message_handler_req_lib_tmr_timerremainingtimeget (
 	SaAisErrorT error = SA_AIS_OK;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrTimerRemainingTimeGet { id=%u }\n",
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrTimerRemainingTimeGet { id=0x%04x }\n",
 		    (unsigned int)(req_lib_tmr_timerremainingtimeget->timer_id));
 
 	hdb_handle_get (&timer_hdb,
-		(unsigned int)(req_lib_tmr_timerremainingtimeget->timer_id),
+		(hdb_handle_t)(req_lib_tmr_timerremainingtimeget->timer_id),
 		(void *)&timer_instance);
 	if (timer_instance == NULL) {
 		error = SA_AIS_ERR_NOT_EXIST;
@@ -580,7 +595,7 @@ static void message_handler_req_lib_tmr_timerremainingtimeget (
 		(SaTimeT)((api->timer_expire_time_get(timer_instance->timer_handle)) -
 			  (api->timer_time_get()));
 
-	hdb_handle_put (&timer_hdb, (unsigned int)(timer_instance->timer_id));
+	hdb_handle_put (&timer_hdb, (hdb_handle_t)(timer_instance->timer_id));
 
 error_exit:
 
@@ -597,7 +612,7 @@ error_exit:
 
 static void message_handler_req_lib_tmr_timerattributesget (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
 	struct req_lib_tmr_timerattributesget *req_lib_tmr_timerattributesget =
 		(struct req_lib_tmr_timerattributesget *)msg;
@@ -606,11 +621,11 @@ static void message_handler_req_lib_tmr_timerattributesget (
 	SaAisErrorT error = SA_AIS_OK;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrTimerAttributesGet { id=%u }\n",
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrTimerAttributesGet { id=0x%04x }\n",
 		    (unsigned int)(req_lib_tmr_timerattributesget->timer_id));
 
 	hdb_handle_get (&timer_hdb,
-		(unsigned int)(req_lib_tmr_timerattributesget->timer_id),
+		(hdb_handle_t)(req_lib_tmr_timerattributesget->timer_id),
 		(void *)&timer_instance);
 	if (timer_instance == NULL) {
 		error = SA_AIS_ERR_NOT_EXIST;
@@ -621,7 +636,7 @@ static void message_handler_req_lib_tmr_timerattributesget (
 		&timer_instance->timer_attributes,
 		sizeof (SaTmrTimerAttributesT));
 
-	hdb_handle_put (&timer_hdb, (unsigned int)(timer_instance->timer_id));
+	hdb_handle_put (&timer_hdb, (hdb_handle_t)(timer_instance->timer_id));
 
 error_exit:
 
@@ -638,16 +653,14 @@ error_exit:
 
 static void message_handler_req_lib_tmr_timeget (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
-	struct req_lib_tmr_timeget *req_lib_tmr_timeget =
-		(struct req_lib_tmr_timeget *)msg;
 	struct res_lib_tmr_timeget res_lib_tmr_timeget;
 	SaAisErrorT error = SA_AIS_OK;
 	SaTimeT current_time;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrTimeGet\n");
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrTimeGet\n");
 
 	current_time = (SaTimeT)(api->timer_time_get());
 
@@ -667,24 +680,20 @@ static void message_handler_req_lib_tmr_timeget (
 
 static void message_handler_req_lib_tmr_clocktickget (
 	void *conn,
-	void *msg)
+	const void *msg)
 {
-	struct req_lib_tmr_clocktickget *req_lib_tmr_clocktickget =
-		(struct req_lib_tmr_clocktickget *)msg;
 	struct res_lib_tmr_clocktickget res_lib_tmr_clocktickget;
 	SaAisErrorT error = SA_AIS_OK;
 	SaTimeT clock_tick;
 
 	/* DEBUG */
-	log_printf (LOG_LEVEL_NOTICE, "LIB request: saTmrClockTickGet\n");
+	log_printf (LOGSYS_LEVEL_DEBUG, "LIB request: saTmrClockTickGet\n");
 
 	clock_tick = (SaTimeT)((1.0 / CLOCKS_PER_SEC) * 1000000000ULL);
 
 	memcpy (&res_lib_tmr_clocktickget.clock_tick,
 		&clock_tick, sizeof (SaTimeT));
 
-error_exit:
-
 	res_lib_tmr_clocktickget.header.size =
 		sizeof (struct res_lib_tmr_clocktickget);
 	res_lib_tmr_clocktickget.header.id =
